@@ -11,7 +11,7 @@ use warnings;
 
 no warnings qw( threads recursion uninitialized );
 
-our $VERSION = '1.807';
+our $VERSION = '1.808';
 
 ## no critic (BuiltinFunctions::ProhibitStringyEval)
 ## no critic (Subroutines::ProhibitSubroutinePrototypes)
@@ -520,10 +520,12 @@ sub run (@) {
 
    MCE::_restore_state();
 
-   if (!$INC{'Tk.pm'} && ($^S || $ENV{'PERL_IPERL_RUNNING'})) {
-      $_MCE->{$_pid}->shutdown(); # shutdown if in eval state
-      $_->DESTROY() for (@{ $_queue->{$_pid} });
-      delete $_queue->{$_pid};
+   if ($^S || $ENV{'PERL_IPERL_RUNNING'}) {
+      if (!$INC{'Mojo/Base.pm'} && !$INC{'Tk.pm'}) {
+         $_MCE->{$_pid}->shutdown(); # shutdown if in eval state
+         $_->DESTROY() for (@{ $_queue->{$_pid} });
+         delete $_queue->{$_pid};
+      }
    }
 
    return map { @{ $_ } } delete @_tmp{ 1 .. $_order_id - 1 }
@@ -679,7 +681,7 @@ MCE::Stream - Parallel stream model for chaining multiple maps and greps
 
 =head1 VERSION
 
-This document describes MCE::Stream version 1.807
+This document describes MCE::Stream version 1.808
 
 =head1 SYNOPSIS
 
